# cppyml

Optimised Python extension for machine learning based on the [ML++](https://github.com/romanwerpachowski/ML) C++ library.

© 2020-21 Roman Werpachowski.

## Licence

Available under GNU GENERAL PUBLIC LICENSE Version 3.

## Documentation

See [here](https://romanwerpachowski.github.io/ML/cppyml.html).
